from fastapi import FastAPI

class AccidentalVuln():
   def fastapi():
        app = FastAPI()
        @app.get("/")
        async def index():
            return {"message": "Accidental vulnerability added token test"}